#!/bin/bash

# Packager: Filippo "NeverBorn" Mesirca (filippo.mesirca@gmail.com)
# Sources location : 
# - ftp://ftp.openldap.org/pub/OpenLDAP/openldap-stable/openldap-stable-20051018.tgz

# program name/version
softversion='2.3.11'
softname='openldap'
date='20051018'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='1z21'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
openldap: OpenLDAP (version: 2.3.11)
openldap:
openldap: OpenLDAP Software is an open source implementation of the Lightweight
openldap: Directory Access Protocol. The suite includes:
openldap:  - slapd: stand-alone LDAP daemon (server)
openldap:  - slurpd: stand-alone LDAP update replication daemon
openldap:  - libraries implementing the LDAP protocol, and
openldap:  - utilities, tools and sample clients.
openldap:
openldap:
openldap: Compiled for ZenWalk-2.1
EOF

# extract sources
srcdir="openldap-$softversion"
cd $buildir
rm -rf $srcdir
tar zxvf openldap-stable-$date.tgz
cd $srcdir

# set correct permissions
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
 
# set the correct bdb header symlink: this is needed because the
# configure script checkes if the db libraries and header versions
# match. If there's a mismatch, the configure script exits returning an
# error and the package can't be compiled
ln -sf /usr/include/db4/db.h /usr/include/db.h

# configure package for compilation
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
   --prefix=/usr \
   --sysconfdir=/etc \
   --localstatedir=/var \
   --disable-debug \
   --enable-dynamic \
   --enable-syslog \
   --enable-ipv6 \
   --enable-slapd \
   --enable-cleartext \
   --enable-crypt \
   --enable-modules \
   --enable-rlookups \
   --enable-wrappers \
   --enable-bdb \
   --enable-dnssrv \
   --enable-hdb \
   --enable-ldap \
   --enable-ldbm \
   --enable-meta \
   --enable-monitor \
   --enable-null \
   --enable-passwd \
   --enable-perl \
   --enable-relay \
   --enable-overlays \
   --enable-slurpd \
   --with-threads \
   --with-tls \
   --program-prefix="" \
   --program-suffix=""

# make the dependencies
make depend
   
# compile package
make $ntasks

# install package to the target directory
make install DESTDIR=$dest

# copy the doc files
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   ANNOUNCEMENT CHANGES COPYRIGHT INSTALL LICENSE README \
   $dest/usr/doc/$softname-$softversion

# put initialization script in right directory
mkdir -p $dest/etc/rc.d
zcat $buildir/rc.slapd.gz > $dest/etc/rc.d/rc.slapd.new
   
# rename the configuration files
cd $dest/etc/openldap/schema
for cnffile in *.schema *.ldif ; do
  mv ${cnffile} ${cnffile}.new;
done
cd $dest/etc/openldap
mv ldap.conf ldap.conf.new
mv slapd.conf slapd.conf.new

# strip executables 
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)
  
# gzip man pages and info files
gzip -9 $dest/usr/man/*/*

# put the ZenWalk build and other needed files in the right directory
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
cp -a $buildir/doinst.sh.gz $dest/usr/src/$softname-$softversion
cp -a $buildir/rc.slapd.gz $dest/usr/src/$softname-$softversion

# change files ownerships for the $dest/usr/bin and $dest/usr/sbin
chown -R root.bin $dest/usr/bin
chown -R root.bin $dest/usr/sbin

# make the package and move it to the build directory
zcat $buildir/doinst.sh.gz > $dest/install/doinst.sh
cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz $buildir

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5

